############
# DATABASES
############

# database containing PE- and PEN- word with confidence 'true' and multiple semantics roles
# ==========================================================================================
readRDS("./data/PePeNDatabase.rda")
read.delim(file = "./data/PePeNDatabase.txt", na = "NA", sep = "\t")
read.csv(file = "./data/PePeNDatabase.csv", na = "NA", sep = "\t")

# database's structure:
# ----------------------
## 'data.frame':	3623 obs. of  21 variables:
## $ Word                  : chr  "pemerintah" "pemerintah" "pemain" "pemadat" ...
## $ Frequency             : num  78047 78047 34704 34704 17942 ...
## $ RealPe                : logi  FALSE FALSE FALSE FALSE TRUE FALSE ...
## $ RealPeN               : logi  TRUE TRUE TRUE TRUE FALSE TRUE ...
## $ AllomorphPeN          : chr  "pem" "pem" "pe" "pe" ...
## $ BaseWord              : chr  "perintah" "perintah" "main" "madat" ...
## $ BaseWordClass         : chr  "n" "n" "v" "n" ...
## $ BaseFrequency         : num  4315 4315 3800 20 12347 ...
## $ SemanticRole          : chr  "agent" "instrument" "agent" "agent" ...
## $ Semantics             : chr  "who/which_meN-X" "which_is_to_meN-X" "who_ber-X" "who_likes_sucking_X" ...
## $ MorphInd              : chr  "peN+perintah<n>_NSD" "peN+perintah<n>_NSD" "peN+main<v>_NSD" "peN+padat<a>_NSD" ...
## $ Note                  : chr  "" "" "Ber-WithPeN-" "DifferentStemForMorphInd" ...
## $ MorphologicalVariation: chr  "" "" "" "" ...
## $ Typo                  : logi  TRUE TRUE TRUE TRUE FALSE FALSE ...
## $ TypoRevision          : chr  "pemeritah,pemeirntah,pemerinta,pemrintah,pemerintan,pemerinah,pemerntah,pemerinth,pemeintah,pemeritnah,peemrint"| __truncated__ "pemeritah,pemeirntah,pemerinta,pemrintah,pemerintan,pemerinah,pemerntah,pemerinth,pemeintah,pemeritnah,peemrint"| __truncated__ "pemian,pemaen,pemasin,pemein,pemaik,pemailn,pemainn,pemiain,pemjain" "pemian,pemaen,pemasin,pemein,pemaik,pemailn,pemainn,pemiain,pemjain" ...
## $ FreqOfTypo            : chr  "68,24,21,20,19,17,17,8,7,7,6,6,6,4,4,4,4,3,3,3,2,2,2,2,2,2,2,2,2,2,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1" "68,24,21,20,19,17,17,8,7,7,6,6,6,4,4,4,4,3,3,3,2,2,2,2,2,2,2,2,2,2,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1" "20,4,2,2,1,1,1,1,1" "20,4,2,2,1,1,1,1,1" ...
## $ FreeVariance          : logi  FALSE FALSE FALSE FALSE FALSE FALSE ...
## $ Inflection            : chr  "" "" "" "" ...

# columns description:
# ----------------------
# Word                    : derived words with PE- or PEN-
# Frequency               : the token frequency of the derived word in the corpus
# RealPe                  : TRUE if the prefix in Word is PE-
# RealPeN                 : TRUE if the prefix in Word is PEN-
# AllomorphPeN            : the allomorph of the PEN- prefix
# BaseWord                : the base word of Word
# BaseWordClass           : the word category of the base word from Word
# BaseFrequency           : the token frequency of the base word in the corpus
# SemanticRole            : the semantic role of derived words with PE- or PEN-
# Semantics               : the semantics gloss of the specific interpretation of the derived noun
# MorphInd                : output of MorphInd parser
# Note                    : additional information on the derived words
# MorphologicalVariation  : reduplications, particles (e.g.-lah, -pun, per-) or affixes (e.g.-ku, -mu, -nya) as well as the information of 1st or 2nd or 3rd pronoun
# Typo                    : whether the form in the corpus had a spelling error
# TypoRevision            : corrected typo in the database
# FreqOfTypo              : the token frequency of typo
# FreeVariance            : TRUE when several spelling alternants are in use
# Inflection              : reduplications, particles (e.g.-lah, -pun, per-) or affixes (e.g.-ku, -mu, -nya) without the information of 1st or 2nd or 3rd pronoun



# database containing PE- and PEN- word which has inflection in it, with confidence 'true', and single semantic role
# ==================================================================================================================
readRDS("./data/PepenInflectionSingle.rda")
read.delim(file = "./data/PepenInflectionSingle.txt", na = "NA", sep = "\t")
read.csv(file = "./data/PepenInflectionSingle.csv", na = "NA", sep = "\t")

# database's structure:
# ----------------------
## 'data.frame':	2411 obs. of  15 variables:
## $ Word                  : chr  "peanggar" "pebasket" "pebasketnya" "pebiliar" ...
## $ Frequency             : num  22 33 1 31 2 420 1 1 8 2 ...
## $ RealPe                : logi  TRUE TRUE TRUE TRUE TRUE TRUE ...
## $ RealPeN               : logi  FALSE FALSE FALSE FALSE FALSE FALSE ...
## $ AllomorphPeN          : chr  "" "" "" "" ...
## $ BaseWord              : chr  "anggar" "basket" "basket" "biliar" ...
## $ BaseWordClass         : chr  "n" "n" "n" "n" ...
## $ BaseFrequency         : num  106 688 688 113 149 ...
## $ SemanticRole          : chr  "agent" "agent" "agent" "agent" ...
## $ Semantics             : chr  "who_ber-X_as_a_profession" "who_plays_X_as_a_profession" "who_plays_X_as_a_profession" "who_plays_X_as_a_profession" ...
## $ MorphInd              : chr  "peanggar<x>_X--" "pebasket<x>_X--" "pebasketnya<x>_X--" "pebiliar<x>_X--" ...
## $ Note                  : chr  "AnalogyWithPetinju,NonPrefixForMorphInd" "AnalogyWithPetinju,NonPrefixForMorphInd" "AnalogyWithPetinju,NonPrefixForMorphInd" "AnalogyWithPetinju,NonPrefixForMorphInd" ...
## $ MorphologicalVariation: chr  "" "" "Poss3rdSing" "" ...
## $ Typo                  : logi  FALSE FALSE FALSE FALSE FALSE FALSE ...

# columns description:
# ----------------------
# Word                    : derived words with PE- or PEN-
# Frequency               : the token frequency of the derived word in the corpus
# RealPe                  : TRUE if the prefix in Word is PE-
# RealPeN                 : TRUE if the prefix in Word is PEN-
# AllomorphPeN            : the allomorph of the PEN- prefix
# BaseWord                : the base word of Word
# BaseWordClass           : the word category of the base word from Word
# BaseFrequency           : the token frequency of the base word in the corpus
# SemanticRole            : the semantic role of derived words with PE- or PEN-
# Semantics               : the semantics gloss of the specific interpretation of the derived noun
# MorphInd                : output of MorphInd parser
# Note                    : additional information on the derived words
# MorphologicalVariation  : reduplications, particles (e.g.-lah, -pun, per-) or affixes (e.g.-ku, -mu, -nya) as well as the information of 1st or 2nd or 3rd pronoun
# Typo                    : whether the form in the corpus had a spelling error



# database containing PE- and PEN- word which has no inflection in it, with confidence 'true', and single semantic role
# ======================================================================================================================
readRDS("./data/PepenSingleOccurence_NoMorphVar.rda")
read.delim(file = "./data/PepenSingleOccurence_NoMorphVar.txt", na = "NA", sep = "\t")
read.csv(file = "./data/PepenSingleOccurence_NoMorphVar.csv", na = "NA", sep = "\t")

# database's structure:
# ----------------------
## 'data.frame':	1469 obs. of  15 variables:
## $ Word                  : Factor w/ 1592 levels "peanggar","pebasket",..: 1 2 3 4 5 6 7 8 9 10 ...
## $ Frequency             : num  22 33 31 2 420 8 2 2 248 364 ...
## $ RealPe                : logi  TRUE TRUE TRUE TRUE TRUE TRUE ...
## $ RealPeN               : logi  FALSE FALSE FALSE FALSE FALSE FALSE ...
## $ AllomorphPeN          : Factor w/ 8 levels "","pe","pem",..: 1 1 1 1 1 1 1 1 1 1 ...
## $ BaseWord              : Factor w/ 1469 levels "abdi","absah",..: 36 95 154 159 161 167 178 173 188 188 ...
## $ BaseWordClass         : Factor w/ 10 levels "adj","adv","n",..: 3 3 3 3 3 3 3 3 3 3 ...
## $ BaseFrequency         : int  106 688 113 149 12528 12010 53 123 0 0 ...
## $ SemanticRole          : Factor w/ 8 levels "agent","causer",..: 1 1 1 1 1 1 1 1 1 1 ...
## $ Semantics             : Factor w/ 95 levels "place_to_meN-X",..: 54 86 86 86 52 86 86 73 86 86 ...
## $ MorphInd              : Factor w/ 1463 levels "peN+abdi<n>_NSD",..: 1083 1084 1085 1086 1087 1088 1089 1090 1091 1091 ...
## $ Note                  : Factor w/ 68 levels "","AgentBase,AllomorphDeviation",..: 15 15 15 16 33 16 15 7 12 13 ...
## $ MorphologicalVariation: chr  "" "" "" "" ...
## $ Typo                  : logi  FALSE FALSE FALSE FALSE FALSE FALSE ...

# columns description:
# ----------------------
# Word                    : derived words with PE- or PEN-
# Frequency               : the token frequency of the derived word in the corpus
# RealPe                  : TRUE if the prefix in Word is PE-
# RealPeN                 : TRUE if the prefix in Word is PEN-
# AllomorphPeN            : the allomorph of the PEN- prefix
# BaseWord                : the base word of Word
# BaseWordClass           : the word category of the base word from Word
# BaseFrequency           : the token frequency of the base word in the corpus
# SemanticRole            : the semantic role of derived words with PE- or PEN-
# Semantics               : the semantics gloss of the specific interpretation of the derived noun
# MorphInd                : output of MorphInd parser
# Note                    : additional information on the derived words
# MorphologicalVariation  : reduplications, particles (e.g.-lah, -pun, per-) or affixes (e.g.-ku, -mu, -nya) as well as the information of 1st or 2nd or 3rd pronoun
# Typo                    : whether the form in the corpus had a spelling error

# database containing PE- and PEN- prefixes. This database also includes the base of MEN- prefix, BER- prefix, and monomorphemic words 
# =====================================================================================================================================
readRDS("./data/PepenMeberSimple.rda")
read.delim(file = "./data/PepenMeberSimple.txt", na = "NA", sep = "\t")
read.csv(file = "./data/PepenMeberSimple.csv", na = "NA", sep = "\t")

# database's structure:
# ----------------------
## 'data.frame':	1319 obs. of  14 variables:
## $ MeberWord    : Factor w/ 1303 levels "","berajar","berbelanja",..: 5 279 437 6 486 7 496 15 16 982 ...
## $ BaseWord     : Factor w/ 1423 levels "abdi","absah",..: 159 171 204 260 265 271 277 404 451 496 ...
## $ PepenWord    : Factor w/ 1448 levels "peanggar","pebasket",..: 5 8 10 13 14 15 16 19 20 21 ...
## $ PepenFreq    : num  420 2 288 5625 1 ...
## $ RealPe       : logi  TRUE TRUE FALSE TRUE FALSE TRUE ...
## $ RealPeN      : logi  FALSE FALSE TRUE FALSE TRUE FALSE ...
## $ BaseWordClass: Factor w/ 7 levels "adj","adv","n",..: 3 3 3 3 3 3 3 3 3 7 ...
## $ BaseFrequency: int  12528 123 100 1348 559 539 250 142 697 84 ...
## $ Semantics    : Factor w/ 89 levels "place_to_meN-X",..: 52 73 73 54 73 52 80 54 52 73 ...
## $ logPepenFreq : num  6.043 1.099 5.666 8.635 0.693 ...
## $ MeberFreq    : num  451 7 5 390 22 ...
## $ MeN          : chr  "FALSE" "TRUE" "TRUE" "FALSE" ...
## $ Ber          : chr  "TRUE" "FALSE" "FALSE" "TRUE" ...
## $ logMeberFreq : num  6.11 2.08 1.79 5.97 3.14 ...

# columns description:
# ----------------------
# MeberWord               : derived words with MEN- or BER-
# BaseWord                : the base word of Word
# PepenWord               : derived words with PE- or PEN-
# PepenFreq               : the token frequency of derived words with PE- or PEN-
# RealPe                  : TRUE if the prefix in Word is PE-
# RealPeN                 : TRUE if the prefix in Word is PEN-
# BaseWordClass           : the word category of the base word from Word
# BaseFrequency           : the token frequency of the base word in the corpus
# Semantics               : the semantics gloss of the specific interpretation of the derived noun
# logPepenFreq            : PepenFreq on the power of 10
# MeberFreq               : the token frequency of derived words with MEN- or BER-
# MeN                     : TRUE if the prefix in Word is MEN-
# Ber                     : TRUE if the prefix in Word is BER-
# logMeberFreq            : MeberFreq on the power of 10

# database containing indonesian verbs
# =====================================
readRDS("./data/AllVerbs.rda")
read.delim(file = "./data/AllVerbs.txt", na = "NA", sep = "\t")
read.csv(file = "./data/AllVerbs.csv", na = "NA", sep = "\t")

# database's structure:
# ----------------------
## 'data.frame':	26996 obs. of  7 variables:
## $ Word                  : Factor w/ 560634 levels "a","aa","aaa",..: 316894 486892 309543 295797 510777 115978 301379 507463 234212 300084 ...
## $ Frequency             : num  154758 146274 119115 76116 67536 ...
## $ MorphInd              : chr  "meN+jadi<a>_VSA" "sudah<v>_VSA" "meN+kata<n>+kan_VSA" "meN+laku<a>+kan_VSA" ...
## $ BaseWord              : chr  "jadi" "sudah" "kata" "laku" ...
## $ BaseWordClass         : chr  "a" "v" "n" "a" ...
## $ MorphologicalVariation: chr  "" "" "" "" ...
## $ Affix                 : chr  "meN-" "simple" "meN-/-kan" "meN-/-kan" ...

# columns description:
# ----------------------
# Word                    : derived words with verbal affixes
# Frequency               : the token frequency of the derived word in the corpus
# MorphInd                : output of MorphInd parser
# BaseWord                : the base word of Word
# BaseWordClass           : the word category of the base word from Word
# MorphologicalVariation  : reduplications, particles (e.g.-lah, -pun, per-) or affixes (e.g.-ku, -mu, -nya) as well as the information of 1st or 2nd or 3rd pronoun
# Affix                   : information on verbal affix attaching to the base word



# database containing verbs which has MEN- and BER- prefixes
# ===========================================================
readRDS("./data/MeBer.rda")
read.delim(file = "./data/MeBer.txt", na = "NA", sep = "\t")
read.csv(file = "./data/MeBer.csv", na = "NA", sep = "\t")

# database's structure:
# ----------------------
## 'data.frame':	12066 obs. of  11 variables:
## $ Word                  : Factor w/ 48840 levels "be","bea","beaa",..: 32128 18382 23964 22669 22072 3832 27619 19550 12555 34944 ...
## $ Frequency             : int  119115 76116 62317 46242 43803 36567 34002 33316 32206 31950 ...
## $ MeN                   : logi  TRUE TRUE TRUE TRUE TRUE FALSE ...
## $ Ber                   : logi  FALSE FALSE FALSE FALSE FALSE TRUE ...
## $ MeNAllomorph          : Factor w/ 7 levels "","me","mem",..: 5 2 2 3 3 1 4 2 1 5 ...
## $ BaseWord              : chr  "kata" "laku" "milik" "buat" ...
## $ BaseFrequency         : num  151552 1689 12427 8431 1295 ...
## $ MorphInd              : Factor w/ 12897 levels "ber+ab<f>+an_VSA",..: 7131 7777 8543 4758 4539 10 4934 8114 2862 6127 ...
## $ BaseWordClass         : chr  "n" "adj" "v" "v" ...
## $ MorphologicalVariation: chr  "" "" "" "" ...
## $ Inflection            : chr  "FALSE" "FALSE" "FALSE" "FALSE" ...

# columns description:
# ----------------------
# Word                    : derived words with MEN- or BER-
# Frequency               : the token frequency of the derived word in the corpus
# MeN                     : TRUE if the prefix in Word is MEN-
# Ber                     : TRUE if the prefix in Word is BER-
# MeNAllomorph            : the allomorph of the MEN- prefix
# BaseWord                : the base word of Word
# BaseFrequency           : the token frequency of the base word in the corpus
# MorphInd                : output of MorphInd parser
# BaseWordClass           : the word category of the base word from Word
# MorphologicalVariation  : reduplications, particles (e.g.-lah, -pun, per-) or affixes (e.g.-ku, -mu, -nya) as well as the information of 1st or 2nd or 3rd pronoun
# Inflection              : TRUE if there is inflectional affixes attaching the word



# database containing monomorphemic words in the corpus
# ======================================================
# this database contains monomorphemic words as well as the information to which verbal and nominal (PE- and PEN-) affixes they attach to
readRDS("./data/SimpleWords.rda")
read.delim(file = "./data/SimpleWords.txt", na = "NA", sep = "\t")
read.csv(file = "./data/SimpleWords.csv", na = "NA", sep = "\t")