#####################
# LIBRARY OF PACKAGES
#####################
library(xtable)
options(xtable.comment = FALSE,
        xtable.table.placement='!h')
library(itsadug)
library(ggplot2) 
library(plyr) 
library(lattice) 
library(mgcv)
library(gridExtra) 
library(ggpubr)
library(vcd)


#####################################################
# CALCULATION, TABLES, AND FIGURES CODE FOR ANALYSIS
#####################################################
# =======
# Table 8
# ========
pepen = readRDS("./PepenInflectionSingle.rda")
# excluding archaic per-
pepen$Word = as.character(pepen$Word)
pepen$AllomorphPeN = as.character(pepen$AllomorphPeN)
pepen = pepen[pepen$Word !="pertapa"  & pepen$Word != "petapa" & pepen$Word != "perantara" & pepen$Word != "petapa-petapa",]
pepen = pepen[pepen$AllomorphPeN!="per",]

# making table for PE and PEN
v = table(pepen$Word)
f = function(v)sum(v == 1)
PPtypes = table(pepen$RealPe)
names(PPtypes)[1] = "PEN"
names(PPtypes)[2] = "PE"
PPtokens = tapply(pepen$Frequency, pepen$RealPe, sum)
names(PPtokens)[1] = "PEN"
names(PPtokens)[2] = "PE"
PPhapaxes = tapply(pepen$Frequency, pepen$RealPe, f)
names(PPhapaxes)[1] = "PEN"
names(PPhapaxes)[2] = "PE"

dfPPtypes = data.frame(PPtypes)
colnames(dfPPtypes) = c("Prefix", "Types")
dfPPtokens = data.frame(PPtokens)
colnames(dfPPtokens) = "Tokens"
dfPP = cbind(dfPPtypes, dfPPtokens)
dfPPhapaxes = data.frame(PPhapaxes)
colnames(dfPPhapaxes) = "Hapaxes"
dfPP = cbind(dfPP, dfPPhapaxes)

# see the result
dfPP
## note: a small discrepancy emerged for reasons remain unclear

# table for PEN allomorph
pepentypes = table(pepen$AllomorphPeN)
pepentypes = pepentypes[-1]
pepentokens = tapply(pepen$Frequency, pepen$AllomorphPeN, sum)
pepentokens = pepentokens[-1]
pepenhapaxes = tapply(pepen$Frequency, pepen$AllomorphPeN, f)
pepenhapaxes = pepenhapaxes[-1]

dfpepentypes = data.frame(pepentypes)
colnames(dfpepentypes) = c("Prefix", "Counts")
dfpepenhapaxes = data.frame(pepenhapaxes)
colnames(dfpepenhapaxes) = "Counts"
dfpepenhapaxes$Prefix = rownames(dfpepenhapaxes)
dfpepentokens = data.frame(pepentokens)
dfpepentokens$Prefix = rownames(dfpepentokens)
colnames(dfpepentokens)[1] = "Tokens"
colnames(dfpepentypes)[2] = "Types"
colnames(dfpepenhapaxes)[1] = "Hapaxes"
df_pepen = merge(dfpepentokens, dfpepentypes, by= "Prefix")
df_pepen = merge(df_pepen, dfpepenhapaxes, by= "Prefix")
df_pepen = df_pepen[(order(df_pepen[,2])),]

df_pepen$Prefix = c("penge-", "peny-", "peng-", "pen-", "pe-", "pem-")

# see the result
df_pepen


# =========
# Figure 1
# =========
pepen = readRDS("./data/PepenSingleOccurence_NoMorphVar.rda")
# excluding archaic per-
pepen$Word = as.character(pepen$Word)
pepen$AllomorphPeN = as.character(pepen$AllomorphPeN)
pepen = pepen[pepen$Word !="pertapa"  & pepen$Word != "petapa" & pepen$Word != "perantara" & pepen$Word != "petapa-petapa",]
pepen = pepen[pepen$AllomorphPeN!="per",]

tmp = unique(pepen[,c("Word", "Frequency", "RealPe", "RealPeN")])
PeData = tmp[tmp$RealPe == TRUE,]
PeData = PeData[rev(order(PeData$Frequency)),]  
PeData$Rank = 1:nrow(PeData)
PeNData = tmp[tmp$RealPeN == TRUE,]
PeNData = PeNData[rev(order(PeNData$Frequency)),]
PeNData$Rank = 1:nrow(PeNData)

# pe VS peN allomorphs
tmp = unique(pepen[,c("Word", "Frequency", "RealPe", "RealPeN", "AllomorphPeN")])
PeData = tmp[tmp$RealPe == TRUE,]
PeData = PeData[rev(order(PeData$Frequency)),]  # rev is to reverse the order, most frequent will be on the top
PeData$Rank = 1:nrow(PeData)
PeNDataPe = tmp[tmp$AllomorphPeN == "pe",]
PeNDataPe = PeNDataPe[rev(order(PeNDataPe$Frequency)),]
PeNDataPe$Rank = 1:nrow(PeNDataPe)
PeNDataPem = tmp[tmp$AllomorphPeN == "pem",]
PeNDataPem = PeNDataPem[rev(order(PeNDataPem$Frequency)),]
PeNDataPem$Rank = 1:nrow(PeNDataPem)
PeNDataPen = tmp[tmp$AllomorphPeN == "pen",]
PeNDataPen = PeNDataPen[rev(order(PeNDataPen$Frequency)),]
PeNDataPen$Rank = 1:nrow(PeNDataPen)
PeNDataPeng = tmp[tmp$AllomorphPeN == "peng",]
PeNDataPeng = PeNDataPeng[rev(order(PeNDataPeng$Frequency)),]
PeNDataPeng$Rank = 1:nrow(PeNDataPeng)
PeNDataPeny = tmp[tmp$AllomorphPeN == "peny",]
PeNDataPeny = PeNDataPeny[rev(order(PeNDataPeny$Frequency)),]
PeNDataPeny$Rank = 1:nrow(PeNDataPeny)
PeNDataPenge = tmp[tmp$AllomorphPeN == "penge",]
PeNDataPenge = PeNDataPenge[rev(order(PeNDataPenge$Frequency)),]
PeNDataPenge$Rank = 1:nrow(PeNDataPenge)

par(mfrow = c(1,2), mar = c(5,6,1,1), oma = c(0,0,0,0))
plot(PeData$Rank, PeData$Frequency, log = "xy", 
     xlim = c(1,5000), ylim = c(1, 80000), 
     type = "s", # connect the dots
     col = "red", 
     cex.lab = 1.1,
     cex.axis = 1.1,
     xlab = "Rank", ylab = "log Frequency")

lines(PeNData$Rank, PeNData$Frequency, type = "s", col = "blue")

legend("topright", 
       c("PE-","PEN-"), 
       lty=c(1,1), 
       bty = "n",
       cex = 0.9,
       col=c("red","blue"))

plot(PeData$Rank, PeData$Frequency, log = "xy", 
     xlim = c(1,5000), ylim = c(1, 80000), 
     type = "s", 
     col = "red", 
     cex.lab = 1.1,
     cex.axis = 1.1,
     xlab = "Rank", ylab = "log Frequency")

lines(PeNDataPe$Rank, PeNDataPe$Frequency, col = "blue")
lines(PeNDataPem$Rank, PeNDataPem$Frequency, col = "black")
lines(PeNDataPen$Rank, PeNDataPen$Frequency, col = "brown")
lines(PeNDataPeng$Rank, PeNDataPeng$Frequency, col = "yellow")
lines(PeNDataPeny$Rank, PeNDataPeny$Frequency, col = "green")
lines(PeNDataPenge$Rank, PeNDataPenge$Frequency, col = "grey")

legend("topright", 
       c("PE-","PEN:pe-", "PEN:pem-", "PEN:pen-", "PEN:peng-", "PEN:peny-", "PEN:penge-"), 
       lty=c(1,1), 
       bty = "n",
       cex = 0.9,
       col=c("red","blue", "black", "brown", "yellow", "green", "grey")) 


# ====================================
# Productivity index for PE- and PEN-
# ====================================
round(dfPP$Hapaxes[1]/dfPP$Tokens[1],5)
round(dfPP$Hapaxes[2]/dfPP$Tokens[2],5)


# =========
# Figure 2
# =========
meber = readRDS("./MeBer.rda")
meber_NoMorphVar = meber[meber$Inflection==FALSE,]

v = table(meber_NoMorphVar$Word)
f = function(v)sum(v == 1)
mebertypes = table(meber_NoMorphVar$MeNAllomorph)
names(mebertypes)[1] = "ber"
mebertokens = tapply(meber_NoMorphVar$Frequency, meber_NoMorphVar$MeNAllomorph, sum)
names(mebertokens)[1] = "ber"
meberhapaxes = tapply(meber_NoMorphVar$Frequency, meber_NoMorphVar$MeNAllomorph, f)
names(meberhapaxes)[1] = "ber"

dfmebertokens = data.frame(mebertokens)
dfmebertypes = data.frame(mebertypes)
df = cbind(dfmebertokens, dfmebertypes)
df$Var1 = NULL
df = df[(order(df[,1])),]
pref = data.frame(Prefix = c("menge-", "meny-", "mem-", "me-", "meng-", "men-", "BER-"))
df2 = cbind(df, pref)
colnames(df2) = c("Tokens", "Types", "Prefix")
df3 = df2[,c(3,1,2)]
dfmeberhapaxes = data.frame(meberhapaxes)
dfmeberhapaxes = dfmeberhapaxes[c(7, 6, 3, 2, 5, 4, 1),]
df4 = cbind(df3, dfmeberhapaxes)
colnames(df4)[4] = "Hapaxes"
MenBer = df4[,-1]
MenBer = MenBer[(order(MenBer[,2])),]
MenBer = MenBer[c(2,3,4,5,6,7,1),]

pepen_single_nomorphvar = readRDS("./PepenSingleOccurence_NoMorphVar.rda")
# excluding archaic per-
pepen_single_nomorphvar$Word = as.character(pepen_single_nomorphvar$Word)
pepen_single_nomorphvar$AllomorphPeN = as.character(pepen_single_nomorphvar$AllomorphPeN)
pepen_single_nomorphvar = pepen_single_nomorphvar[pepen_single_nomorphvar$Word !="pertapa"  & pepen_single_nomorphvar$Word != "petapa" & pepen_single_nomorphvar$Word != "perantara" & pepen_single_nomorphvar$Word != "petapa-petapa",]
pepen_single_nomorphvar = pepen_single_nomorphvar[pepen_single_nomorphvar$AllomorphPeN!="per",]

v = table(pepen_single_nomorphvar$Word)
f = function(v)sum(v == 1)
pepentypes = table(pepen_single_nomorphvar$AllomorphPeN)
names(pepentypes)[1] = "PE"
types = pepentypes[c("peny", "pe", "pem", "pen", "peng", "PE", "penge")]
names(types)[6] = "PE-types"
pepentokens = tapply(pepen_single_nomorphvar$Frequency, pepen_single_nomorphvar$AllomorphPeN, sum)
names(pepentokens)[1] = "PE"
tokens = pepentokens[c("peny", "pe", "pem", "pen", "peng", "PE", "penge")]
pepenhapaxes = tapply(pepen_single_nomorphvar$Frequency, pepen_single_nomorphvar$AllomorphPeN, f)
names(pepenhapaxes)[1] = "PE"
hapaxes = pepenhapaxes[c("peny", "pe", "pem", "pen", "peng", "PE", "penge")]
names(hapaxes)[6] = "PE-hapaxes"

plot(0,0, type = 'n', ylim = c(0,600), xlim = c(150, 3300), xlab = "Verb prefix (MEN-, BER-)", ylab = "Noun prefix (PEN-, PE-)")
text(MenBer$Types, types, names(types), col=ifelse(names(types)=="PE-types", "dark red", "dark blue"), adj = 0)
text(MenBer$Types, hapaxes, names(hapaxes), col=ifelse(names(hapaxes)=="PE-hapaxes", "red", "blue"), adj = 0)

abline(lm(types[-6]~MenBer$Types[-6]), lty = 1, col = "dark blue") # -6 sama -5 karena kita mau keluarin realPe and ber
abline(lm(hapaxes[-6]~MenBer$Types[-6]), lty = 2, col = "blue")

legend("topleft", 
       c("types","hapaxes"), 
       lty=c(1,2), 
       bty = "n", 
       col=c("dark blue","blue")) 

# ========
# Table 9
# ========
pepen = readRDS("./PepenInflectionSingle.rda")
# excluding archaic per-
pepen$Word = as.character(pepen$Word)
pepen$AllomorphPeN = as.character(pepen$AllomorphPeN)
pepen = pepen[pepen$Word !="pertapa"  & pepen$Word != "petapa" & pepen$Word != "perantara" & pepen$Word != "petapa-petapa",]
pepen = pepen[pepen$AllomorphPeN!="per",]

tab1 = table(pepen$AllomorphPeN, pepen$SemanticRole)
rownames(tab1) = c("PE-", "pe-", "pem-", "pen-", "peng-", "penge-", "peny-")

allpepen_hapaxes = pepen[pepen$Frequency == 1,]
tab2 = table(allpepen_hapaxes$AllomorphPeN, allpepen_hapaxes$SemanticRole)
rownames(tab2) = c("PE-", "pe-", "pem-", "pen-", "peng-", "penge-", "peny-")

# see the result for the upper table
tab1
## note: a small discrepancy emerged for reasons remain unclear
# see the result for the lower table
tab2

# assymetry in patient for PE- and PEN-
chisq.test(matrix(c(2217, 188, 10, 15), 2,2))

# chi-squared test indication that the ratios of agents to instruments are proportional across all allomorphs
# on types
tab4 = tab1[-1,c(1, 3)]
chisq.test(tab4)
# on hapaxes
tab5 = tab2[-1,c(1,3)]
chisq.test(tab5)

# proportionality for agent and instrument within peN- allomorphs
pepen2 = pepen[pepen$MorphologicalVariation=="",]
tab8 = table(pepen2$AllomorphPeN, pepen2$SemanticRole)
rownames(tab8) = c("PE-", "pe-", "pem-", "pen-", "peng-", "penge-", "peny-")
allpepen_hapaxes = pepen2[pepen2$Frequency == 1,]
tab9 = table(allpepen_hapaxes$AllomorphPeN, allpepen_hapaxes$SemanticRole)
rownames(tab9) = c("PE-", "pe-", "pem-", "pen-", "peng-", "penge-", "peny-")

# on types
tab10 = tab8[-1,c(1, 3)]
chisq.test(tab10)

# on hapaxes
tab11 = tab9[-1,c(1,3)]
chisq.test(tab11)

# ========
# Table 10
# ========
pepen.infl = readRDS("./PepenInflectionSingle.rda")
# excluding archaic per-
pepen.infl$Word = as.character(pepen.infl$Word)
pepen.infl$AllomorphPeN = as.character(pepen.infl$AllomorphPeN)
pepen.infl = pepen.infl[pepen.infl$Word !="pertapa"  & pepen.infl$Word != "petapa" & pepen.infl$Word != "perantara"& pepen.infl$Word != "petapa-petapa",]
pepen.infl = pepen.infl[pepen.infl$AllomorphPeN!="per",]

pepen.infl[pepen.infl$Inflection=="Clitic",]$Inflection = "BoundMorpheme"

tab = table(pepen.infl$Inflection, pepen.infl$AllomorphPeN)
colnames(tab)[1] = "PE"
colnames(tab)[2] = "pe"
rownames(tab)[1] = "base"

# see the result
tab


# ==========
# Figure 4
# =========
pepen.infl = readRDS("./PepenInflectionSingle6.rda")
# excluding archaic per-
pepen.infl$Word = as.character(pepen.infl$Word)
pepen.infl$AllomorphPeN = as.character(pepen.infl$AllomorphPeN)
pepen.infl = pepen.infl[pepen.infl$Word !="pertapa"  & pepen.infl$Word != "petapa" & pepen.infl$Word != "perantara"& pepen.infl$Word != "petapa-petapa",]
pepen.infl = pepen.infl[pepen.infl$AllomorphPeN!="per",]

pepen2 = pepen.infl
pepen2 = pepen2[pepen2$AllomorphPeN %in% c("","pe","pem", "pen", "peng", "peny", "penge"),]
pepen2 = pepen2[!is.element(pepen2$Inflection, c("Clitic", "Possession+Particle", "Reduplication+Particle")),]
pepen2 = droplevels(pepen2)
tab4 = table(pepen2$Inflection, pepen2$AllomorphPeN == "")
rownames(tab4)[1] = "base"
colnames(tab4)[1] = "PEN"
colnames(tab4)[2] = "PE"
test = chisq.test(tab4)
rownames(tab4) = c("base", "part", "poss", "redup", "redup+poss")

mosaicplot(tab4, main = "", shade=TRUE, color = FALSE)


# ======================
# Figure 5 AND TABLE 11
# ======================
simple = readRDS("./SimpleWords.rda")
simple = simple[simple$BaseWordClass=="adj" | simple$BaseWordClass=="n" | simple$BaseWordClass=="v",]

simple$WithPe = simple$RealPe == "TRUE"
simple$WithPen = simple$PeN == "TRUE"
simple$logVerbAffixCounts = log(simple$VerbAffixCounts+1)
simple$logBaseFreq_cent = as.numeric(scale(log(simple$BaseFreq)))
simple$type = "pe"
simple$type[simple$WithPen==TRUE] = "peN"
simple$type[simple$WithPen==FALSE & simple$WithPe==FALSE] = "neither"
simple$type = as.factor(simple$type)

simple$type2 = simple$type
levels(simple$type2) = c("neitherPe", "neitherPe", "peN")
gam_pepen2 = bam(VerbAffixCounts~type2+s(logBaseFreq_cent, by = type2, k = 5), data = simple, family = "poisson")

# Table 11
# ========
summary(gam_pepen2)

# Figure 5
# ========
par(mfrow = c(1,2))
plot(gam_pepen2, select = 1, scheme = 1, shade.col = "steelblue2", rug = FALSE, 
     ylab = "count", main = "without PEN-", ylim = c(0, 3), xlab = "centered log base frequency",
     shift = 0.779)
rug(unique(simple$logBaseFreq_cent[simple$type2=="neitherPe"]))

plot(gam_pepen2, select = 2, scheme = 1, shade.col = "steelblue2", rug = FALSE, 
     ylab = "count", main = "with PEN-", ylim = c(0, 3), xlab = "centered log base frequency",
     shift = 0.779+0.944)
rug(unique(simple$logBaseFreq_cent[simple$type2=="peN"]))



# =========
# Figure 6
# =========
simple = readRDS("./SimpleWords.rda")
simple = simple[simple$BaseWordClass=="adj" | simple$BaseWordClass=="n" | simple$BaseWordClass=="v",]

simple$WithPe = simple$RealPe == "TRUE"
simple$WithPen = simple$PeN == "TRUE"
simple$logVerbAffixCounts = log(simple$VerbAffixCounts+1)
simple$logBaseFreq_cent = as.numeric(scale(simple$logBaseFreq))

simple$type = "pe"
simple$type[simple$WithPen==TRUE] = "peN"
simple$type[simple$WithPen==FALSE & simple$WithPe==FALSE] = "neither"
simple$type = as.factor(simple$type)

simplepe = simple[simple$type=="pe" & simple$VerbAffixCounts>0,]
simplepe_tab = table(simplepe$BaseWordClass)
simplepe0 = simple[simple$type=="pe" & simple$VerbAffixCounts==0,]
simplepe0_tab = table(simplepe0$BaseWordClass)

simpleneither = simple[simple$type=="neither" & simple$VerbAffixCounts>0,]
simpleneither_tab = table(simpleneither$BaseWordClass)
simpleneither0 = simple[simple$type=="neither" & simple$VerbAffixCounts==0,]
simpleneither0_tab = table(simpleneither0$BaseWordClass)

simplepeN = simple[simple$type=="peN" & simple$VerbAffixCounts>0,]
simplepeN_tab = table(simplepeN$BaseWordClass)
simplepeN0 = simple[simple$type=="peN" & simple$VerbAffixCounts==0,]
simplepeN0_tab = table(simplepeN0$BaseWordClass)

origin = data.frame(simplepe_tab, simplepeN_tab, simpleneither_tab)
origin = origin[,-c(3,5)]
colnames(origin) = c("WordCategory", "PE", "PEN", "neither")
origin = origin[,c(1, 4, 3, 2)]
origin2 = matrix(unlist(origin), 3)
origin3 = origin2[,-1]
colnames(origin3) = c("neither", "PEN", "PE")
rownames(origin3) = c("adjective", "noun", "verb")

NoVerbsAffix = data.frame(simplepe0_tab, simplepeN0_tab, simpleneither0_tab)
NoVerbsAffix = NoVerbsAffix[,-c(3,5)]
colnames(NoVerbsAffix) = c("WordCategory", "PE", "PEN", "neither")
NoVerbsAffix = NoVerbsAffix[,c(1, 4, 3, 2)]
NoVerbsAffix2 = matrix(unlist(NoVerbsAffix), 3)
NoVerbsAffix3 = NoVerbsAffix2[,-1]
colnames(NoVerbsAffix3) = c("neither", "PEN", "PE")
rownames(NoVerbsAffix3) = c("adjective", "noun", "verb")

options(scipen = 5)

mosaic(origin3, shade = TRUE, legend = TRUE, gp = shading_Friendly(lty = 1, eps = NULL),
       labeling_args = list(set_varnames = c(A = "word category", B = "nominalization present")))

mosaic(NoVerbsAffix3, shade = TRUE, legend = TRUE, gp = shading_Friendly(lty = 1, eps = NULL),
       labeling_args = list(set_varnames = c(A = "word category", B = "nominalization present")))

# PEN- overrepresentatation for verbs
chisq.test(origin3)
chisq.test(NoVerbsAffix3)


# ========
# TABLE 12
# ========
meber = readRDS("./MeBer.rda")
meber_NoMorphVar = meber[meber$Inflection==FALSE,]
meber_NoMorphVar = meber_NoMorphVar[complete.cases(meber_NoMorphVar), ]

v = table(meber_NoMorphVar$Word)
f = function(v)sum(v == 1)
mebertypes = table(meber_NoMorphVar$MeNAllomorph)
names(mebertypes)[1] = "ber"
mebertokens = tapply(meber_NoMorphVar$Frequency, meber_NoMorphVar$MeNAllomorph, sum)
names(mebertokens)[1] = "ber"
meberhapaxes = tapply(meber_NoMorphVar$Frequency, meber_NoMorphVar$MeNAllomorph, f)
names(meberhapaxes)[1] = "ber"

dfmebertokens = data.frame(mebertokens)
dfmebertypes = data.frame(mebertypes)
dfmebertypes$Freq = as.numeric(dfmebertypes$Freq)
df = cbind(dfmebertokens, dfmebertypes)
df$Var1 = NULL
df = df[(order(df[,1])),]

pref = data.frame(Preffix = c("MEN-: menge-", "MEN-: meny-", "MEN-: me-", "MEN-: mem-", "MEN-: men-", "MEN-: meng-", "BER-"))
df2 = cbind(df, pref)
colnames(df2) = c("Tokens", "Types", "Prefix")
df3 = df2[,c(3,1,2)]

dfmeberhapaxes = data.frame(meberhapaxes)
dfmeberhapaxes = dfmeberhapaxes[c(7, 6, 2, 3, 4, 5, 1),]
df4 = cbind(df3, dfmeberhapaxes)
colnames(df4)[4] = "Hapaxes"

# see the result
df4



# =========
# FIGURE 7
# =========
meber = readRDS("./MeBer.rda")
meber_NoMorphVar = meber[meber$Inflection==FALSE,]
meber_NoMorphVar = meber_NoMorphVar[complete.cases(meber_NoMorphVar), ]
tmp = unique(meber_NoMorphVar[,c("Word", "Frequency", "MeN", "Ber")])
MenData = tmp[tmp$MeN == TRUE,]
MenData = MenData[rev(order(MenData$Frequency)),] 
MenData$Rank = 1:nrow(MenData)
BerData = tmp[tmp$Ber == TRUE,]
BerData = BerData[rev(order(BerData$Frequency)),]
BerData$Rank = 1:nrow(BerData)

# ber VS meN allomorphs
tmp = unique(meber_NoMorphVar[,c("Word", "Frequency", "MeN", "Ber", "MeNAllomorph")])
BerData = tmp[tmp$Ber == TRUE,]
BerData = BerData[rev(order(BerData$Frequency)),]  
BerData$Rank = 1:nrow(BerData)
MeNDataMe = tmp[tmp$MeNAllomorph == "me",]
MeNDataMe = MeNDataMe[rev(order(MeNDataMe$Frequency)),]
MeNDataMe$Rank = 1:nrow(MeNDataMe)
MeNDataMem = tmp[tmp$MeNAllomorph == "mem",]
MeNDataMem = MeNDataMem[rev(order(MeNDataMem$Frequency)),]
MeNDataMem$Rank = 1:nrow(MeNDataMem)
MeNDataMen = tmp[tmp$MeNAllomorph == "men",]
MeNDataMen = MeNDataMen[rev(order(MeNDataMen$Frequency)),]
MeNDataMen$Rank = 1:nrow(MeNDataMen)
MeNDataMeng = tmp[tmp$MeNAllomorph == "meng",]
MeNDataMeng = MeNDataMeng[rev(order(MeNDataMeng$Frequency)),]
MeNDataMeng$Rank = 1:nrow(MeNDataMeng)
MeNDataMeny = tmp[tmp$MeNAllomorph == "meny",]
MeNDataMeny = MeNDataMeny[rev(order(MeNDataMeny$Frequency)),]
MeNDataMeny$Rank = 1:nrow(MeNDataMeny)
MeNDataMenge = tmp[tmp$MeNAllomorph == "menge",]
MeNDataMenge = MeNDataMenge[rev(order(MeNDataMenge$Frequency)),]
MeNDataMenge$Rank = 1:nrow(MeNDataMenge)

par(mfrow = c(1,2), mar = c(5,6,1,1), oma = c(0,0,0,0))
plot(BerData$Rank, BerData$Frequency, log = "xy", 
     # pch = ".", 
     xlim = c(1,10000), ylim = c(1, 100000), 
     type = "s", 
     col = "red", 
     cex.lab = 1.1,
     cex.axis = 1.1,
     xlab = "Rank", ylab = "Frequency") 
lines(MenData$Rank, MenData$Frequency, col = "blue")

legend("topright", 
       c("BER-","MEN-"), 
       lty=c(1,1), 
       bty = "n",
       cex = 0.9,
       col=c("red","blue")) 

plot(BerData$Rank, BerData$Frequency, log = "xy", 
     xlim = c(1,10000), ylim = c(1, 100000), 
     type = "s", 
     col = "red", 
     cex.lab = 1.1,
     cex.axis = 1.1,
     xlab = "Rank", ylab = "Frequency")

lines(MeNDataMe$Rank, MeNDataMe$Frequency, col = "blue")
lines(MeNDataMem$Rank, MeNDataMem$Frequency, col = "black")
lines(MeNDataMen$Rank, MeNDataMen$Frequency, col = "brown")
lines(MeNDataMeng$Rank, MeNDataMeng$Frequency, col = "yellow")
lines(MeNDataMeny$Rank, MeNDataMeny$Frequency, col = "green")
lines(MeNDataMenge$Rank, MeNDataMenge$Frequency, col = "grey")

legend("topright", 
       c("BER-","me-", "mem-", "men-", "meng-", "meny-", "menge-"), 
       lty=c(1,1), 
       bty = "n",
       cex = 0.9,
       col=c("red","blue", "black", "brown", "yellow", "green", "grey"))


# CORRELATION TEST
# ================
pepenmebersimple = readRDS("./PepenMeberSimple.rda")
x = pepenmebersimple[pepenmebersimple$RealPeN == TRUE & pepenmebersimple$MeN == TRUE, ]
x2 = pepenmebersimple[pepenmebersimple$RealPeN == FALSE & pepenmebersimple$MeN == FALSE, ]
# correlation test for peN and meN
cor.test(x$logMeberFreq, x$logPepenFreq, method = "sp")
# correlation test for pe and ber
cor.test(x2$logMeberFreq, x2$logPepenFreq, method = "sp")